Stan Math Library: stan/math/prim/scal/meta/OperandsAndPartials.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

OperandsAndPartials.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_OPERANDSANDPARTIALS_HPP
2 #define STAN_MATH_PRIM_SCAL_META_OPERANDSANDPARTIALS_HPP
3
4 #include <stan/math/prim/scal/meta/return_type.hpp>
5 #include <stan/math/prim/scal/meta/VectorView.hpp>
6
7
8 namespace stan {
9 namespace math {
10
34 template<typename T1 = double, typename T2 = double, typename T3 = double,
35 typename T4 = double, typename T5 = double, typename T6 = double,
36 typename T_return_type
37 = typename stan::return_type<T1, T2, T3, T4, T5, T6>::type>
38 struct OperandsAndPartials {
39 VectorView<T_return_type, false, true> d_x1;
40 VectorView<T_return_type, false, true> d_x2;
41 VectorView<T_return_type, false, true> d_x3;
42 VectorView<T_return_type, false, true> d_x4;
43 VectorView<T_return_type, false, true> d_x5;
44 VectorView<T_return_type, false, true> d_x6;
45
56 OperandsAndPartials(const T1& x1 = 0, const T2& x2 = 0,
57 const T3& x3 = 0, const T4& x4 = 0,
58 const T5& x5 = 0, const T6& x6 = 0) { }
59
67 T_return_type
68 value(double value) {
69 return value;
70 }
71 };
72
73 }
74 }
75 #endif
stan::math::OperandsAndPartials::d_x2
VectorView< T_return_type, false, true > d_x2
Definition: OperandsAndPartials.hpp:40
stan::math::OperandsAndPartials::OperandsAndPartials
OperandsAndPartials(const T1 &x1=0, const T2 &x2=0, const T3 &x3=0, const T4 &x4=0, const T5 &x5=0, const T6 &x6=0)
Constructor.
Definition: OperandsAndPartials.hpp:56
stan
Definition: log_sum_exp.hpp:8
stan::math::OperandsAndPartials::value
T_return_type value(double value)
Returns a T_return_type with the value specified with the partial derivatves.
Definition: OperandsAndPartials.hpp:68
return_type.hpp
stan::math::OperandsAndPartials::d_x6
VectorView< T_return_type, false, true > d_x6
Definition: OperandsAndPartials.hpp:44
stan::return_type::type
boost::math::tools::promote_args< typename scalar_type< T1 >::type, typename scalar_type< T2 >::type, typename scalar_type< T3 >::type, typename scalar_type< T4 >::type, typename scalar_type< T5 >::type, typename scalar_type< T6 >::type >::type type
Definition: return_type.hpp:27
stan::math::OperandsAndPartials
This class builds partial derivatives with respect to a set of operands.
Definition: OperandsAndPartials.hpp:38
VectorView.hpp
stan::math::OperandsAndPartials::d_x3
VectorView< T_return_type, false, true > d_x3
Definition: OperandsAndPartials.hpp:41
stan::VectorView< T_return_type, false, true >
stan::math::OperandsAndPartials::d_x5
VectorView< T_return_type, false, true > d_x5
Definition: OperandsAndPartials.hpp:43
stan::math::OperandsAndPartials::d_x1
VectorView< T_return_type, false, true > d_x1
Definition: OperandsAndPartials.hpp:39
stan::math::OperandsAndPartials::d_x4
VectorView< T_return_type, false, true > d_x4
Definition: OperandsAndPartials.hpp:42

[ Stan Home Page ] © 2011–2016, Stan Development Team.